from django.shortcuts import render
from django.views import View
from django.views.generic.detail import DetailView
from django.views.generic.list import ListView
from django.views.generic.edit import CreateView, UpdateView
from django.http.response import HttpResponseRedirect
from .models import Books, Author
from .forms import BookForm, AuthorForm

def home_view(request):
	return render(request, 'home.html')

class BooksDetailView(DetailView):
	model = Books
	template_name = "bookshelf/book_detais.html"

class BooksView(ListView):
	model = Books
	template_name = "bookshelf/books.html"

class AuthorsView(ListView):
	model = Author
	template_name = "bookshelf/authors.html"

class AuthorDetailsView(DetailView):
	model = Author
	template_name = "bookshelf/author_details.html"

class BookCreateView(CreateView):
	model = Books
	fields = '__all__'
	template_name = "bookshelf/add-book.html"

	def post(self, request,*args,**kwargs):
		form = BookForm(request.POST) 
	
		if form.is_valid():
			new_book = form.save()
			url = "../" + new_book.get_absolute_url() +"/details/"
			return HttpResponseRedirect(url)
		else:
			return render(request, self.template_name, {'form': form})

class AuthorCreateView(CreateView):
	model = Author 
	fields = '__all__'
	template_name = "bookshelf/add-author.html"

	def post(self, request,*args,**kwargs):
		form = AuthorForm(request.POST) 
	
		if form.is_valid():
			new_author = form.save()
			url = "../" + new_author.get_absolute_url() + "/details/"
			return HttpResponseRedirect(url)
		else:
			return render(request, self.template_name, {'form': form})

class BookUpdateView(UpdateView):
	model = Books
	fields = '__all__'
	template_name = "bookshelf/edit-book.html"

	success_url = "../details"

class AuthorUpdateView(UpdateView):
	model = Author 
	fields = '__all__'
	template_name = "bookshelf/edit-author.html"
	
	success_url = "../details"
	
	